@@ -17,11 +17,11 @@ Artifactory::Client - Perl client for Artifactory REST API
 
 =head1 VERSION
 
-Version 0.1.19
+Version 0.1.20
 
 =cut
 
-our $VERSION = '0.1.19';
+our $VERSION = '0.1.20';
 
 =head1 SYNOPSIS
 
@@ -592,6 +592,19 @@ sub move_item {
     return $self->_handle_item( %args );
 }
 
+=head2 get_repository_replication_configuration
+
+Get repository replication configuration
+
+=cut
+
+sub get_repository_replication_configuration {
+    my $self = shift;
+    my ( $artifactory, $port, $repository ) = $self->_unpack_attributes( 'artifactory', 'port', 'repository' );
+    my $url = "$artifactory:$port/artifactory/api/replications/$repository";
+    return $self->get( $url );
+}
+
 =head2 scheduled_replication_status
 
 Gets scheduled replication status of a repository
